@@ -51,6 +51,8 @@
 
 #define PANEL_ACTION_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_ACTION_BUTTON, PanelActionButtonPrivate))
 
+#define LOGOUT_PROMPT_KEY "/apps/gnome-session/options/logout_prompt"
+
 enum {
 	PROP_0,
 	PROP_ACTION_TYPE,
@@ -153,9 +155,20 @@ panel_action_lock_invoke_menu (PanelActionButton *button,
 static void
 panel_action_logout (GtkWidget *widget)
 {
-	panel_logout_new (PANEL_LOGOUT_DIALOG_LOGOUT,
-			  gtk_widget_get_screen (widget),
-			  gtk_get_current_event_time ());
+	gboolean not_prompt;
+
+	not_prompt = gconf_client_get_bool (panel_gconf_get_client (),
+					    LOGOUT_PROMPT_KEY, NULL);
+	/* this avoids handling errors from gconf since prompting is
+	 * safer */
+	not_prompt = !not_prompt;
+
+	if (not_prompt)
+		panel_session_request_logout ();
+	else
+		panel_logout_new (PANEL_LOGOUT_DIALOG_LOGOUT,
+				  gtk_widget_get_screen (widget),
+				  gtk_get_current_event_time ());
 }
 
 static void
@@ -292,7 +305,7 @@ static PanelAction actions [] = {
 		PANEL_ACTION_RUN,
 		PANEL_RUN_ICON,
 		N_("Run Application..."),
-		N_("Run an Application by entering a command"),
+		N_("Run an application by typing a command or choosing from a list"),
 		"gospanel-555",
 		"ACTION:run:NEW",
 		panel_action_run_program, NULL, NULL,
@@ -302,7 +315,7 @@ static PanelAction actions [] = {
 		PANEL_ACTION_SEARCH,
 		"gnome-searchtool",
 		N_("Search for Files..."),
-		N_("Find files, folders, and documents on your computer"),
+		N_("Locate documents and folders on this computer by name or content"),
 		"gospanel-554",
 		"ACTION:search:NEW",
 		panel_action_search, NULL, NULL, NULL
@@ -321,7 +334,7 @@ static PanelAction actions [] = {
 		PANEL_ACTION_CONNECT_SERVER,
 		"gnome-globe", //FIXME icon
 		N_("Connect to Server..."),
-		N_("Connect to a remote server"), //FIXME
+		N_("Connect to a remote computer or shared disk"),
 		"gospanel-563", //FIXME
 		"ACTION:connect-server:NEW",
 		panel_action_connect_server, NULL, NULL, NULL
