@@ -44,7 +44,8 @@ static GConfEnumStringPair panel_orient_map [] = {
 	{ PANEL_ORIENT_UP,    "panel-orient-up" },
 	{ PANEL_ORIENT_DOWN,  "panel-orient-down" },
 	{ PANEL_ORIENT_LEFT,  "panel-orient-left" },
-	{ PANEL_ORIENT_RIGHT, "panel-orient-right" }
+	{ PANEL_ORIENT_RIGHT, "panel-orient-right" },
+	{ 0,                  NULL }
 };
 
 static gboolean
@@ -69,6 +70,7 @@ panel_compatibility_map_orient_string (const char  *str,
 static GConfEnumStringPair panel_orientation_map [] = {
 	{ GTK_ORIENTATION_HORIZONTAL, "panel-orientation-horizontal" },
 	{ GTK_ORIENTATION_VERTICAL,   "panel-orientation-vertical" },
+	{ 0,                          NULL }
 };
 
 
@@ -103,6 +105,7 @@ static GConfEnumStringPair panel_edge_map [] = {
 	{ BORDER_RIGHT,  "panel-edge-right" },
 	{ BORDER_BOTTOM, "panel-edge-bottom" },
 	{ BORDER_LEFT,   "panel-edge-left" },
+	{ 0,             NULL }
 };
 
 static gboolean
@@ -140,6 +143,7 @@ static GConfEnumStringPair panel_type_map [] = {
 	{ SLIDING_PANEL,   "sliding-panel" },
 	{ FLOATING_PANEL,  "floating-panel" },
 	{ MENU_PANEL,      "menu-panel" },
+	{ 0,               NULL }
 };
 
 static gboolean
@@ -169,6 +173,7 @@ static GConfEnumStringPair panel_size_map [] = {
 	{ PANEL_SIZE_LARGE,    "panel-size-large" },
 	{ PANEL_SIZE_X_LARGE,  "panel-size-x-large" },
 	{ PANEL_SIZE_XX_LARGE, "panel-size-xx-large" },
+	{ 0,                   NULL }
 };
 
 static gboolean
@@ -194,6 +199,7 @@ static GConfEnumStringPair panel_background_type_map [] = {
 	{ PANEL_BACK_NONE,   "no-background" },
 	{ PANEL_BACK_COLOR,  "color-background" },
 	{ PANEL_BACK_IMAGE,  "pixmap-background" },
+	{ 0,                 NULL }
 };
 
 static gboolean
@@ -817,7 +823,7 @@ panel_compatibility_migrate_objects (GConfClient       *client,
 				break;
 			}
 		}
-
+		g_free (object_type_str);
 		g_free (l->data);
 	}
 	g_slist_free (objects);
@@ -1065,3 +1071,45 @@ panel_compatibility_migrate_applications_scheme (GConfClient *client,
 
 	g_free (location);
 }
+
+void
+panel_compatiblity_migrate_screenshot_action (GConfClient *client,
+					      const char  *id)
+{
+	const char *key;
+
+	panel_profile_remove_from_list (PANEL_GCONF_OBJECTS, id);
+
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id,
+				    "launcher_location");
+	gconf_client_set_string (client, key, "gnome-screenshot.desktop", NULL);
+
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id,
+				    "object_type");
+	//FIXME: ideally, we would use panel_object_type_map, but it's private
+	//in panel-profile.c
+	gconf_client_set_string (client, key, "launcher-object", NULL);
+
+	panel_profile_add_to_list (PANEL_GCONF_OBJECTS, id);
+}
+
+void
+panel_compatiblity_migrate_settings_menu_button (GConfClient *client,
+						 const char  *id)
+{
+	const char *key;
+
+	panel_profile_remove_from_list (PANEL_GCONF_OBJECTS, id);
+
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id,
+				    "launcher_location");
+	gconf_client_set_string (client, key, "gnomecc.desktop", NULL);
+
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id,
+				    "object_type");
+	//FIXME: ideally, we would use panel_object_type_map, but it's private
+	//in panel-profile.c
+	gconf_client_set_string (client, key, "launcher-object", NULL);
+
+	panel_profile_add_to_list (PANEL_GCONF_OBJECTS, id);
+}
